@@ -142,7 +142,7 @@ class Database(common.BaseObject):
 
     @property
     def system_js(self):
-        """A :class:`SystemJS` helper for this :class:`Database`.
+        """**DEPRECATED**: :class:`SystemJS` helper for this :class:`Database`.
 
         See the documentation for :class:`SystemJS` for more details.
         """
@@ -160,39 +160,61 @@ class Database(common.BaseObject):
 
     @property
     def incoming_manipulators(self):
-        """All incoming SON manipulators installed on this instance.
+        """**DEPRECATED**: All incoming SON manipulators.
+
+        .. versionchanged:: 3.5
+          Deprecated.
 
         .. versionadded:: 2.0
         """
+        warnings.warn("Database.incoming_manipulators() is deprecated",
+                      DeprecationWarning, stacklevel=2)
+
         return [manipulator.__class__.__name__
                 for manipulator in self.__incoming_manipulators]
 
     @property
     def incoming_copying_manipulators(self):
-        """All incoming SON copying manipulators installed on this instance.
+        """**DEPRECATED**: All incoming SON copying manipulators.
+
+        .. versionchanged:: 3.5
+          Deprecated.
 
         .. versionadded:: 2.0
         """
+        warnings.warn("Database.incoming_copying_manipulators() is deprecated",
+                      DeprecationWarning, stacklevel=2)
+
         return [manipulator.__class__.__name__
                 for manipulator in self.__incoming_copying_manipulators]
 
     @property
     def outgoing_manipulators(self):
-        """List all outgoing SON manipulators
-        installed on this instance.
+        """**DEPRECATED**: All outgoing SON manipulators.
+
+        .. versionchanged:: 3.5
+          Deprecated.
 
         .. versionadded:: 2.0
         """
+        warnings.warn("Database.outgoing_manipulators() is deprecated",
+                      DeprecationWarning, stacklevel=2)
+
         return [manipulator.__class__.__name__
                 for manipulator in self.__outgoing_manipulators]
 
     @property
     def outgoing_copying_manipulators(self):
-        """List all outgoing SON copying manipulators
-        installed on this instance.
+        """**DEPRECATED**: All outgoing SON copying manipulators.
+
+        .. versionchanged:: 3.5
+          Deprecated.
 
         .. versionadded:: 2.0
         """
+        warnings.warn("Database.outgoing_copying_manipulators() is deprecated",
+                      DeprecationWarning, stacklevel=2)
+
         return [manipulator.__class__.__name__
                 for manipulator in self.__outgoing_copying_manipulators]
 
@@ -324,9 +346,14 @@ class Database(common.BaseObject):
             :class:`~pymongo.read_concern.ReadConcern`. If ``None`` (the
             default) the :attr:`read_concern` of this :class:`Database` is
             used.
+          - `collation` (optional): An instance of
+            :class:`~pymongo.collation.Collation`.
           - `**kwargs` (optional): additional keyword arguments will
             be passed as options for the create collection command
 
+        .. versionchanged:: 3.4
+           Added the collation option.
+
         .. versionchanged:: 3.0
            Added the codec_options, read_preference, and write_concern options.
 
@@ -378,19 +405,27 @@ class Database(common.BaseObject):
 
     def _command(self, sock_info, command, slave_ok=False, value=1, check=True,
                  allowable_errors=None, read_preference=ReadPreference.PRIMARY,
-                 codec_options=DEFAULT_CODEC_OPTIONS, **kwargs):
+                 codec_options=DEFAULT_CODEC_OPTIONS,
+                 write_concern=None,
+                 parse_write_concern_error=False, **kwargs):
         """Internal command helper."""
         if isinstance(command, string_type):
             command = SON([(command, value)])
+
+        if sock_info.max_wire_version >= 5 and write_concern:
+            command['writeConcern'] = write_concern.document
+
         command.update(kwargs)
 
-        return sock_info.command(self.__name,
-                                 command,
-                                 slave_ok,
-                                 read_preference,
-                                 codec_options,
-                                 check,
-                                 allowable_errors)
+        return sock_info.command(
+            self.__name,
+            command,
+            slave_ok,
+            read_preference,
+            codec_options,
+            check,
+            allowable_errors,
+            parse_write_concern_error=parse_write_concern_error)
 
     def command(self, command, value=1, check=True,
                 allowable_errors=None, read_preference=ReadPreference.PRIMARY,
@@ -539,6 +574,15 @@ class Database(common.BaseObject):
         :Parameters:
           - `name_or_collection`: the name of a collection to drop or the
             collection object itself
+
+        .. note:: The :attr:`~pymongo.database.Database.write_concern` of
+           this database is automatically applied to this operation when using
+           MongoDB >= 3.4.
+
+        .. versionchanged:: 3.4
+           Apply this database's write concern automatically to this operation
+           when connected to MongoDB >= 3.4.
+
         """
         name = name_or_collection
         if isinstance(name, Collection):
@@ -550,7 +594,13 @@ class Database(common.BaseObject):
 
         self.__client._purge_index(self.__name, name)
 
-        self.command("drop", _unicode(name), allowable_errors=["ns not found"])
+        with self.__client._socket_for_reads(
+                ReadPreference.PRIMARY) as (sock_info, slave_ok):
+            return self._command(
+                sock_info, 'drop', slave_ok, _unicode(name),
+                allowable_errors=['ns not found'],
+                write_concern=self.write_concern,
+                parse_write_concern_error=True)
 
     def validate_collection(self, name_or_collection,
                             scandata=False, full=False):
@@ -938,9 +988,9 @@ class Database(common.BaseObject):
                 return
             raise
 
-    def authenticate(self, name, password=None,
+    def authenticate(self, name=None, password=None,
                      source=None, mechanism='DEFAULT', **kwargs):
-        """Authenticate to use this database.
+        """**DEPRECATED**: Authenticate to use this database.
 
         Authentication lasts for the life of the underlying client
         instance, or until :meth:`logout` is called.
@@ -964,7 +1014,9 @@ class Database(common.BaseObject):
             distinct client instances.
 
         :Parameters:
-          - `name`: the name of the user to authenticate.
+          - `name`: the name of the user to authenticate. Optional when
+            `mechanism` is MONGODB-X509 and the MongoDB server version is
+            >= 3.4.
           - `password` (optional): the password of the user to authenticate.
             Not used with GSSAPI or MONGODB-X509 authentication.
           - `source` (optional): the database to authenticate on. If not
@@ -978,6 +1030,11 @@ class Database(common.BaseObject):
             name for GSSAPI authentication pass
             authMechanismProperties='SERVICE_NAME:<service name>'
 
+        .. versionchanged:: 3.5
+           Deprecated. Authenticating multiple users conflicts with support for
+           logical sessions in MongoDB 3.6. To authenticate as multiple users,
+           create multiple instances of MongoClient.
+
         .. versionadded:: 2.8
            Use SCRAM-SHA-1 with MongoDB 3.0 and later.
 
@@ -989,7 +1046,7 @@ class Database(common.BaseObject):
 
         .. mongodoc:: authenticate
         """
-        if not isinstance(name, string_type):
+        if name is not None and not isinstance(name, string_type):
             raise TypeError("name must be an "
                             "instance of %s" % (string_type.__name__,))
         if password is not None and not isinstance(password, string_type):
@@ -1020,7 +1077,10 @@ class Database(common.BaseObject):
         return True
 
     def logout(self):
-        """Deauthorize use of this database for this client instance."""
+        """**DEPRECATED**: Deauthorize use of this database."""
+        warnings.warn("Database.logout() is deprecated",
+                      DeprecationWarning, stacklevel=2)
+
         # Sockets will be deauthenticated as they are used.
         self.client._purge_credentials(self.name)
 
@@ -1049,18 +1109,7 @@ class Database(common.BaseObject):
         return self[dbref.collection].find_one({"_id": dbref.id}, **kwargs)
 
     def eval(self, code, *args):
-        """Evaluate a JavaScript expression in MongoDB.
-
-        Useful if you need to touch a lot of data lightly; in such a
-        scenario the network transfer of the data could be a
-        bottleneck. The `code` argument must be a JavaScript
-        function. Additional positional arguments will be passed to
-        that function when it is run on the server.
-
-        Raises :class:`TypeError` if `code` is not an instance of
-        :class:`basestring` (:class:`str` in python 3) or `Code`.
-        Raises :class:`~pymongo.errors.OperationFailure` if the eval
-        fails. Returns the result of the evaluation.
+        """**DEPRECATED**: Evaluate a JavaScript expression in MongoDB.
 
         :Parameters:
           - `code`: string representation of JavaScript code to be
@@ -1071,6 +1120,9 @@ class Database(common.BaseObject):
         .. warning:: the eval command is deprecated in MongoDB 3.0 and
           will be removed in a future server version.
         """
+        warnings.warn("Database.eval() is deprecated",
+                      DeprecationWarning, stacklevel=2)
+
         if not isinstance(code, Code):
             code = Code(code)
 
@@ -1087,30 +1139,17 @@ class Database(common.BaseObject):
 
 
 class SystemJS(object):
-    """Helper class for dealing with stored JavaScript.
+    """**DEPRECATED**: Helper class for dealing with stored JavaScript.
     """
 
     def __init__(self, database):
-        """Get a system js helper for the database `database`.
+        """**DEPRECATED**: Get a system js helper for the database `database`.
 
-        An instance of :class:`SystemJS` can be created with an instance
-        of :class:`Database` through :attr:`Database.system_js`,
-        manual instantiation of this class should not be necessary.
-
-        :class:`SystemJS` instances allow for easy manipulation and
-        access to server-side JavaScript:
-
-        .. doctest::
-
-          >>> db.system_js.add1 = "function (x) { return x + 1; }"
-          >>> db.system.js.find({"_id": "add1"}).count()
-          1
-          >>> db.system_js.add1(5)
-          6.0
-          >>> del db.system_js.add1
-          >>> db.system.js.find({"_id": "add1"}).count()
-          0
+        SystemJS will be removed in PyMongo 4.0.
         """
+        warnings.warn("SystemJS is deprecated",
+                      DeprecationWarning, stacklevel=2)
+
         if not database.write_concern.acknowledged:
             database = database.client.get_database(
                 database.name, write_concern=WriteConcern())
